@@ -3,7 +3,7 @@ import re
 from lxml import etree as et
 
 
-def clean_wits(wits: list[str]) -> str:
+def clean_wits(wits) -> str:
     cleaned_wits = list(wits)
     for wit in wits:
         if 'c' not in wit:
@@ -14,13 +14,12 @@ def clean_wits(wits: list[str]) -> str:
     return ' '.join(cleaned_wits)
 
 
-def remove_redundant_correctors(input_addr: str):
+def remove_redundant_correctors(input_addr):
     tei_ns = 'http://www.tei-c.org/ns/1.0'
 
     parser = et.XMLParser(remove_blank_text=True)
     xml = et.parse(input_addr, parser)
-    rdg: et._Element
-    for rdg in xml.xpath('//tei:rdg', namespaces={'tei': tei_ns}): #type: et._Element
+    for rdg in xml.xpath('//tei:rdg', namespaces={'tei': tei_ns}):
         wits = rdg.get('wit').split()
         cleaned_wits = clean_wits(wits)
         rdg.attrib['wit'] = cleaned_wits
